from webtest import TestApp as Client
from .fixtures import (
    template,
    template_inheritance,
    override_template,
    override_template_inheritance,
)


def test_template():
    c = Client(template.App())

    response = c.get("/persons/world")
    assert (
        response.body
        == b"""\
<html>
<body>
<p>Hello world!</p>
</body>
</html>"""
    )


def test_override_template():
    c = Client(override_template.App())

    response = c.get("/persons/world")
    assert (
        response.body
        == b"""\
<html>
<body>
<p>Hello world!</p>
</body>
</html>"""
    )

    c = Client(override_template.SubApp())

    response = c.get("/persons/world")
    assert (
        response.body
        == b"""\
<html>
<body>
<p>Hi world!</p>
</body>
</html>"""
    )


def test_template_inheritance():
    c = Client(template_inheritance.App())

    response = c.get("/persons/world")
    assert (
        response.body
        == b"""\
<html>
<head>
</head>
<body>
<div id="content">
<p>Hello world!</p>
</div>
</body>
</html>"""
    )


def test_override_template_inheritance():
    c = Client(override_template_inheritance.App())

    response = c.get("/persons/world")
    assert (
        response.body
        == b"""\
<html>
<head>
</head>
<body>
<div id="content">
<p>Hello world!</p>
</div>
</body>
</html>"""
    )

    c = Client(override_template_inheritance.SubApp())

    response = c.get("/persons/world")
    assert (
        response.body
        == b"""\
<html>
<head>
</head>
<body>
<div id="content2">
<p>Hello world!</p>
</div>
</body>
</html>"""
    )



from setuptools import setup, find_packages

long_description = "\n".join(
    (
        open("README.rst", encoding="utf-8").read(),
        open("CHANGES.txt", encoding="utf-8").read(),
    )
)

setup(
    name="more.jinja2",
    version="0.3",
    description="Jinja2 template integration for Morepath",
    long_description=long_description,
    author="Martijn Faassen",
    author_email="faassen@startifact.com",
    keywords="morepath jinja2",
    license="BSD",
    url="https://github.com/morepath/more.jinja2",
    namespace_packages=["more"],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    python_requires=">=3.6",
    install_requires=["setuptools", "morepath >= 0.15", "Jinja2 >= 2.9"],
    extras_require=dict(test=["pytest >= 7", "pytest-cov", "WebTest"]),
)



from more.jinja2 import Jinja2App


class App(Jinja2App):
    pass


@App.path(path="persons/{name}")
class Person:
    def __init__(self, name):
        self.name = name


@App.template_directory()
def get_template_dir():
    return "templates"


@App.html(model=Person, template="person_inherit.jinja2")
def person_default(self, request):
    return {"name": self.name}
